@@ -3,7 +3,7 @@
 
 package HiD::App::Command::server;
 {
-  $HiD::App::Command::server::VERSION = '0.9';
+  $HiD::App::Command::server::VERSION = '1.0';
 }
 BEGIN {
   $HiD::App::Command::server::AUTHORITY = 'cpan:GENEHACK';
@@ -23,7 +23,17 @@ use feature     qw/ unicode_strings /;
 use namespace::autoclean;
 
 use Plack::Runner;
-use AnyEvent::Filesys::Notify;
+
+
+has auto_refresh => (
+  is            => 'ro',
+  isa           => 'Bool',
+  traits        => [ 'Getopt' ],
+  cmd_aliases   => [ qw/ auto A / ],
+  documentation => 'auto re-publish when source changes, Default=False',
+  lazy          => 1,
+  default       => 0,
+);
 
 
 has port => (
@@ -45,15 +55,6 @@ sub _build_port {
   return $self->config->{server_port} // 5000;
 }
 
-
-has auto_refresh => (
-    is          => 'ro',
-    isa         => 'Bool',
-    traits      => ['Getopt'],
-    cmd_aliases => 'auto',
-    lazy        => 1,
-    default     => 0,
-);
 sub _run {
   my( $self , $opts , $args ) = @_;
 
@@ -61,47 +62,29 @@ sub _run {
 
   my $app = HiD::Server->new( root => $self->destination )->to_app;
 
+  my %args = ( -p => $self->port );
+
   # auto refresh
   if ( $self->auto_refresh ) {
-      my @dirs;
+    my @dirs = map { $self->hid->get_config($_) } qw/ include_dir layout_dir posts_dir /;
 
-      # posts, include and layout
-      for my $dir (qw/posts_dir include_dir layout_dir/) {
-           push @dirs, $self->hid->get_config($dir);
-      }
+    for my $dir (qw/pages regular_files/) {
+      push @dirs, map { $_->input_filename } @{ $self->hid->$dir };
+    }
 
-      # regular_files and pages
-      for my $dir (qw/pages regular_files/) {
-          push @dirs, map { $_->input_filename } @{ $self->hid->$dir };
-      }
+    $args{'-R'} = join ',', @dirs;
+    $args{'-r'} = 1;
 
-      say "*** auto refresh, watching at:";
-      say foreach @dirs;
-      say "***";
-      my $building = 0;
-      AnyEvent::Filesys::Notify->new(
-          dirs => \@dirs,
-          interval => 1.0,
-          filter => sub { shift !~ /\.(swap|#|~)$/ },
-          backend => $^O eq 'darwin' ? 'KQueue' : '', # Mac::FSEvents do not support watch at file
-          cb => sub {
-              return if $building;
-              $building = 1;
-              say 'Rebuilding ... ';
-              $self->_set_hid( HiD->new({
-                  cli_opts => $self->hid->cli_opts,
-                  config_file => $self->hid->config_file,
-              }));
-              $self->publish;
-              $building = 0;
-          }
-      );
-      eval "use Twiggy; 1" or
-          die "You should install Twiggy when use --auto_refresh option.";
+    my $original_app = $app;
+    $app = \sub {
+      say 'Rebuild ... ';
+      $self->publish;
+      $original_app;
+    };
   }
 
   my $runner = Plack::Runner->new;
-  $runner->parse_options( -p => $self->port );
+  $runner->parse_options(%args);
   $runner->run($app);
 }
 
@@ -153,14 +136,14 @@ Start a Plack-based web server that serves your C<destination> directory.
 
 =head1 ATTRIBUTES
 
-=head2 port
-
-Port number to bind. Defaults to 5000.
-
 =head2 auto_refresh
 
 Automatically refresh result when source file/dir changed, just likey jekyll
 
+=head2 port
+
+Port number to bind. Defaults to 5000.
+
 =head1 SEE ALSO
 
 See L<HiD::App::Command> for additional command line options supported by all
@@ -168,7 +151,7 @@ sub commands.
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 AUTHOR
 
