@@ -3,7 +3,7 @@
 
 package HiD::Page;
 {
-  $HiD::Page::VERSION = '0.9';
+  $HiD::Page::VERSION = '1.0';
 }
 BEGIN {
   $HiD::Page::AUTHORITY = 'cpan:GENEHACK';
@@ -53,12 +53,14 @@ sub _build_url {
 
   my $naive = join '/' , $path_frag , $self->basename;
 
+  my %_valid_exts = map { $_=>1 } qw(rss xml html htm xhtml xhtm shtml shtm);
+  my $ext = exists $_valid_exts{$self->ext} ? $self->ext : 'html';
+
   my $url;
-  given( $format ) {
-    when( 'none'   ) { $url = $naive . '.html' }
-    when( 'pretty' ) { $url = $naive . '/'     }
-    default          { $url = "/$format"       }
-  }
+
+  if(    $format eq 'none'   ) { $url = $naive . ".$ext" }
+  elsif( $format eq 'pretty' ) { $url = $naive . '/'     }
+  else                         { $url = "/$format"       }
 
   $url =~ s|//+|/|g;
 
@@ -112,7 +114,7 @@ object from this class works.
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 AUTHOR
 
