@@ -1,9 +1,9 @@
-# ABSTRACT: Plugin
+# ABSTRACT: Base class for plugins
 
 
 package HiD::Plugin;
 {
-  $HiD::Plugin::VERSION = '0.9';
+  $HiD::Plugin::VERSION = '1.0';
 }
 BEGIN {
   $HiD::Plugin::AUTHORITY = 'cpan:GENEHACK';
@@ -15,9 +15,9 @@ use namespace::autoclean;
 use 5.014;
 use utf8;
 use autodie;
-use warnings qw/ FATAL utf8 /;
-use charnames   qw/ :full           /;
-use feature  qw/ unicode_strings /;
+use warnings   qw/ FATAL utf8 /;
+use charnames  qw/ :full           /;
+use feature    qw/ unicode_strings /;
 
 sub after_publish { 1 }
 
@@ -31,20 +31,20 @@ __END__
 
 =head1 NAME
 
-HiD::Plugin - Plugin
+HiD::Plugin - Base class for plugins
 
 =head1 SYNOPSIS
 
-    my $plugin = HiD::Plugin;
+    my $plugin = HiD::Plugin->new;
     $plugin->after_publish($hid);
 
 =head1 DESCRIPTION
 
-Class representing a "Plugin" object.
+Base class for plugin object
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 AUTHOR
 
