@@ -3,7 +3,7 @@
 
 package HiD::Role::IsConverted;
 {
-  $HiD::Role::IsConverted::VERSION = '0.9';
+  $HiD::Role::IsConverted::VERSION = '1.0';
 }
 BEGIN {
   $HiD::Role::IsConverted::AUTHORITY = 'cpan:GENEHACK';
@@ -21,10 +21,10 @@ use feature     qw/ unicode_strings /;
 
 use Carp;
 use Class::Load  qw/ :all /;
+use Encode;
 use File::Slurp  qw/ read_file /;
 use HiD::Types;
 use YAML::XS     qw/ Load /;
-use Encode;
 
 requires 'get_default_layout';
 
@@ -36,36 +36,43 @@ has content => (
 );
 
 
-### FIXME make this extensible
-my %conversion_extension_map = (
-  markdown => [ 'Text::Markdown' , 'markdown' ] ,
-  mkdn     => [ 'Text::Markdown' , 'markdown' ] ,
-  mk       => [ 'Text::Markdown' , 'markdown' ] ,
-  textile  => [ 'Text::Textile'  , 'process'  ] ,
-);
-
 has converted_content => (
   is      => 'ro' ,
   isa     => 'Str' ,
   lazy    => 1 ,
   default => sub {
     my $self = shift;
+    return _convert_by_extension( $self->content , $self->ext );
+  }
+);
 
-    return $self->content
-      unless exists $conversion_extension_map{ $self->ext };
 
-    my( $module , $method ) =
-      @{ $conversion_extension_map{ $self->ext }};
-    load_class( $module );
+has converted_excerpt => (
+  is      => 'ro' ,
+  isa     => 'Str' ,
+  lazy    => 1 ,
+  default => sub {
+    my $self = shift;
 
-    return $module->new->$method( $self->content );
+    my $converted_excerpt = _convert_by_extension( $self->excerpt , $self->ext );
+
+    if ( $self->excerpt ne $self->content ) {
+      # Add the "read more" link
+      ### FIXME this should be configurable
+      $converted_excerpt .= q{<p class="readmore"><a href="}
+        . $self->url
+          . q{" class="readmore">read more</a></p>};
+    }
+
+    return $converted_excerpt;
   },
 );
 
 
 has hid => (
-  is  => 'ro' ,
-  isa => 'HiD' ,
+  is       => 'ro' ,
+  isa      => 'HiD' ,
+  required => 1 ,
 );
 
 
@@ -121,7 +128,7 @@ has template_data => (
       site     => $self->hid ,
     };
 
-    foreach my $method ( qw/ title url categories tags/ ) {
+    foreach my $method ( qw/ categories date tags title url / ) {
       $data->{page}{$method} = $self->$method
         if $self->can( $method );
     }
@@ -159,6 +166,31 @@ around BUILDARGS => sub {
   return $class->$orig( \%args );
 };
 
+{ # hide the map
+
+  ### FIXME make this extensible
+  my %conversion_extension_map = (
+    markdown => [ 'Text::Markdown' , 'markdown' ] ,
+    mkdn     => [ 'Text::Markdown' , 'markdown' ] ,
+    mk       => [ 'Text::Markdown' , 'markdown' ] ,
+    md       => [ 'Text::Markdown' , 'markdown' ] ,
+    textile  => [ 'Text::Textile'  , 'process'  ] ,
+  );
+
+  sub _convert_by_extension {
+    my( $content , $extension ) = @_;
+
+    return $content
+      unless exists $conversion_extension_map{ $extension };
+
+    my( $module , $method ) = @{ $conversion_extension_map{ $extension }};
+    load_class( $module );
+
+    my $converted = $module->new->$method( $content );
+    return $converted;
+  }
+}
+
 no Moose::Role;
 1;
 
@@ -199,6 +231,10 @@ Page content (stuff after the YAML front matter)
 
 Content after it has gone through the conversion process.
 
+=head2 converted_excerpt ( ro / Str / lazily built from content )
+
+Excerpt after it has gone through the conversion process
+
 =head2 hid
 
 The HiD object for the current site. Here primarily to provide access to site
@@ -222,7 +258,7 @@ Data for passing to template processing function.
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 AUTHOR
 
