@@ -3,7 +3,7 @@
 
 package HiD::Role::IsPost;
 {
-  $HiD::Role::IsPost::VERSION = '0.9';
+  $HiD::Role::IsPost::VERSION = '1.0';
 }
 BEGIN {
   $HiD::Role::IsPost::AUTHORITY = 'cpan:GENEHACK';
@@ -94,6 +94,30 @@ has date => (
 );
 
 
+has excerpt => (
+  is      => 'ro',
+  isa     => 'Str',
+  lazy    => 1,
+  builder => '_build_excerpt',
+);
+
+sub _build_excerpt {
+  my $self = shift;
+
+  my $content = $self->content;
+
+  return unless defined $content;
+
+  my $sep = $self->hid->excerpt_separator;
+
+  if($content =~ /^$sep/mp) {
+    return ${^PREMATCH};
+  }
+
+  return $content;
+}
+
+
 has tags => (
   is      => 'ro' ,
   isa     => 'ArrayRef',
@@ -189,13 +213,19 @@ post-specific attributes and methods.
 
 DateTime object for this post.
 
+=head2 excerpt
+
+It is generally useful to summarize or lead a post with a "read more" tag
+added to the end of the post.  This is ideal for a blog where we might not
+want to list the full post on the front page.
+
 =head2 tags
 
 =head2 title
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 AUTHOR
 
